import 'package:mncapps/data/model/cachingstrategy.dart';
import 'package:mncapps/data/model/responsedata.dart';
import 'package:mncapps/data/service/service.dart';
import 'package:mncapps/data/sharepref/sharedpref.dart';
import 'package:package_info_plus/package_info_plus.dart';

abstract class Repo with SharedPref, Service {
  Future<ResponseData> getDataRepo(
      {required String userID,
      required CachingStrategy cachingStrategy}) async {
    final info = await PackageInfo.fromPlatform();
    final packagename = info.packageName;
    try {
      if (cachingStrategy == CachingStrategy.None) {
        //Network
        final data = await getDataNetwork(userID, packagename);
        await setDataSavedTimeSP();
        await setDataSP(data);
        return data;
      }

      final lastSaved = await getDataSavedTimeSP();
      if (lastSaved == null) {
        //Network
        final data = await getDataNetwork(userID, packagename);
        await setDataSavedTimeSP();
        await setDataSP(data);
        return data;
      }

      final lastDay = DateTime.now().add(cachingStrategy.getDuration());
      if ((lastDay.day - lastSaved.day) > cachingStrategy.getValue()) {
        //Network
        final data = await getDataNetwork(userID, packagename);
        await setDataSavedTimeSP();
        await setDataSP(data);
        return data;
      }

      return await getDataSP();
    } catch (e) {
      rethrow;
    }
  }
}
