import 'dart:io';

import 'package:device_apps/device_apps.dart';
import 'package:flutter/material.dart';
import 'package:mncapps/data/model/appsmodel.dart';
import 'package:mncapps/widget/inappwebview.dart';
import 'package:url_launcher/url_launcher.dart';

mixin ButtonUtils {
  Future<bool> getInstalledStatus({required AppsModel data}) async {
    if (Platform.isIOS) {
      String scheme = data.ios.scheme;
      return await canLaunchUrl(Uri.parse(scheme));
    }
    if (Platform.isAndroid) {
      Uri playstoreURL = Uri.dataFromString(data.android.store);
      String id = playstoreURL.queryParameters['id']!;
      final app = await DeviceApps.getApp(id);
      return app != null;
    }
    return false;
  }

  Future<String> getButtonLabel(
      {required AppsModel data, required bool installed}) async {
    if (data.open == 'web') return 'OPEN';
    return installed ? "OPEN" : "INSTALL";
  }

  Future<void> openFunction(
      {required BuildContext context,
      required AppsModel data,
      required bool installed}) async {
    if (Platform.isAndroid) {
      if (data.open == 'store') {
        launchUrl(Uri.parse(data.android.store));
        return;
      }
      if (data.open == 'web') {
        Navigator.push(
            context,
            MaterialPageRoute(
                builder: (context) => InAppWebview(url: data.webUrl)));
        return;
      }
      if (data.open == 'app') {
        if (installed) {
          Uri playstoreURL = Uri.dataFromString(data.android.store);
          String id = playstoreURL.queryParameters['id']!;
          DeviceApps.openApp(id);
          return;
        }
        launchUrl(Uri.parse(data.android.store));
        return;
      }
    }

    if (Platform.isIOS) {
      if (data.open == 'store') {
        launchUrl(Uri.parse(data.ios.store));
        return;
      }
      if (data.open == 'web') {
        Navigator.push(
            context,
            MaterialPageRoute(
                builder: (context) => InAppWebview(url: data.webUrl)));
        return;
      }
      if (data.open == 'app') {
        if (installed) {
          launchUrl(Uri.parse(data.ios.scheme));
          return;
        }
        launchUrl(Uri.parse(data.ios.store));
        return;
      }
    }
  }
}
