import 'package:flutter/material.dart';
import 'package:mncapps/data/interface/mncappsdatainterface.dart';
import 'package:mncapps/data/model/appsmodel.dart';
import 'package:mncapps/data/model/cachingstrategy.dart';
import 'package:mncapps/data/model/layoutmodel.dart';
import 'package:mncapps/widget/mncappsitem.dart';

class MNCAppsBody extends StatefulWidget {
  final String userID;
  final CachingStrategy? cachingStrategy;

  const MNCAppsBody({Key? key, required this.userID, this.cachingStrategy})
      : super(key: key);
  @override
  _MNCAppsBodyState createState() => _MNCAppsBodyState();
}

class _MNCAppsBodyState extends State<MNCAppsBody> {
  List<AppsModel>? items = [];
  LayoutModel? layout;
  MNCAppsDataInterface _dataInterface = MNCAppsDataInterface();
  String? error;

  @override
  void initState() {
    super.initState();
    getData();
  }

  getData() async {
    try {
      final data = await _dataInterface.getDataRepo(
        userID: widget.userID,
        cachingStrategy: widget.cachingStrategy ?? CachingStrategy.None,
      );
      setState(() {
        items = data.items;
        layout = data.layoutModel;
      });
    } catch (e) {
      debugPrint(e.toString());
      error = e.toString();
    }
  }

  @override
  Widget build(BuildContext context) {
    if (items == null) return _ErrorWidget();

    if (items?.isEmpty ?? true) {
      return Container();
    }

    return LayoutBuilder(builder: (context, constraint) {
      if (constraint.maxWidth > 600) {
        return GridView.builder(
          gridDelegate: new SliverGridDelegateWithFixedCrossAxisCount(
            crossAxisCount: 2,
            childAspectRatio: 3.2,
            crossAxisSpacing: 8,
          ),
          padding: EdgeInsets.all(16),
          itemCount: items?.length ?? 0,
          itemBuilder: (context, i) {
            return MoreAppsItem(
              data: items![i],
              layoutModel: layout!,
            );
          },
        );
      }
      return ListView.builder(
          itemCount: items?.length ?? 0,
          padding: EdgeInsets.all(16),
          itemBuilder: (context, i) {
            return MoreAppsItem(
              data: items![i],
              layoutModel: layout!,
            );
          });
    });
  }
}

class _ErrorWidget extends StatelessWidget {
  @override
  Widget build(BuildContext context) {
    return Container(
      width: double.maxFinite,
      height: double.maxFinite,
      child: Center(
        child: Column(
          crossAxisAlignment: CrossAxisAlignment.center,
          mainAxisAlignment: MainAxisAlignment.center,
          children: <Widget>[
            Icon(
              Icons.error_outline_rounded,
              size: 48,
              color: Colors.red,
            ),
            SizedBox(height: 8),
            Text(
              'Error Getting data',
              style: Theme.of(context).textTheme.headlineMedium,
            ),
            Text(
              'Try Again Data',
              style: Theme.of(context).textTheme.titleSmall,
            ),
          ],
        ),
      ),
    );
  }
}
